==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/web/NextJsCommonProjectOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.982Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextJsCommonProjectOptions")
@software.amazon.jsii.Jsii.Proxy(NextJsCommonProjectOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NextJsCommonProjectOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Assets directory.
     * <p>
     * Default: "public"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAssetsdir() {
        return null;
    }

    /**
     * (experimental) Setup Tailwind CSS as a PostCSS plugin.
     * <p>
     * Default: true
     * <p>
     * @see https://tailwindcss.com/docs/installation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTailwind() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NextJsCommonProjectOptions> {
        java.lang.String assetsdir;
        java.lang.Boolean tailwind;

        /**
         * Sets the value of {@link NextJsCommonProjectOptions#getAssetsdir}
         * @param assetsdir Assets directory.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assetsdir(java.lang.String assetsdir) {
            this.assetsdir = assetsdir;
            return this;
        }

        /**
         * Sets the value of {@link NextJsCommonProjectOptions#getTailwind}
         * @param tailwind Setup Tailwind CSS as a PostCSS plugin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(java.lang.Boolean tailwind) {
            this.tailwind = tailwind;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextJsCommonProjectOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NextJsCommonProjectOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextJsCommonProjectOptions {
        private final java.lang.String assetsdir;
        private final java.lang.Boolean tailwind;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.assetsdir = software.amazon.jsii.Kernel.get(this, "assetsdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tailwind = software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.assetsdir = builder.assetsdir;
            this.tailwind = builder.tailwind;
        }

        @Override
        public final java.lang.String getAssetsdir() {
            return this.assetsdir;
        }

        @Override
        public final java.lang.Boolean getTailwind() {
            return this.tailwind;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAssetsdir() != null) {
                data.set("assetsdir", om.valueToTree(this.getAssetsdir()));
            }
            if (this.getTailwind() != null) {
                data.set("tailwind", om.valueToTree(this.getTailwind()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.NextJsCommonProjectOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextJsCommonProjectOptions.Jsii$Proxy that = (NextJsCommonProjectOptions.Jsii$Proxy) o;

            if (this.assetsdir != null ? !this.assetsdir.equals(that.assetsdir) : that.assetsdir != null) return false;
            return this.tailwind != null ? this.tailwind.equals(that.tailwind) : that.tailwind == null;
        }

        @Override
        public final int hashCode() {
            int result = this.assetsdir != null ? this.assetsdir.hashCode() : 0;
            result = 31 * result + (this.tailwind != null ? this.tailwind.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/web/NextJsCommonProjectOptions.java <==
package io.github.cdklabs.projen.web;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.656Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.web.NextJsCommonProjectOptions")
@software.amazon.jsii.Jsii.Proxy(NextJsCommonProjectOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface NextJsCommonProjectOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Assets directory.
     * <p>
     * Default: "public"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAssetsdir() {
        return null;
    }

    /**
     * (experimental) Setup Tailwind CSS as a PostCSS plugin.
     * <p>
     * Default: true
     * <p>
     * @see <a href="https://tailwindcss.com/docs/installation">https://tailwindcss.com/docs/installation</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getTailwind() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<NextJsCommonProjectOptions> {
        java.lang.String assetsdir;
        java.lang.Boolean tailwind;

        /**
         * Sets the value of {@link NextJsCommonProjectOptions#getAssetsdir}
         * @param assetsdir Assets directory.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assetsdir(java.lang.String assetsdir) {
            this.assetsdir = assetsdir;
            return this;
        }

        /**
         * Sets the value of {@link NextJsCommonProjectOptions#getTailwind}
         * @param tailwind Setup Tailwind CSS as a PostCSS plugin.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tailwind(java.lang.Boolean tailwind) {
            this.tailwind = tailwind;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link NextJsCommonProjectOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public NextJsCommonProjectOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link NextJsCommonProjectOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements NextJsCommonProjectOptions {
        private final java.lang.String assetsdir;
        private final java.lang.Boolean tailwind;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.assetsdir = software.amazon.jsii.Kernel.get(this, "assetsdir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.tailwind = software.amazon.jsii.Kernel.get(this, "tailwind", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.assetsdir = builder.assetsdir;
            this.tailwind = builder.tailwind;
        }

        @Override
        public final java.lang.String getAssetsdir() {
            return this.assetsdir;
        }

        @Override
        public final java.lang.Boolean getTailwind() {
            return this.tailwind;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAssetsdir() != null) {
                data.set("assetsdir", om.valueToTree(this.getAssetsdir()));
            }
            if (this.getTailwind() != null) {
                data.set("tailwind", om.valueToTree(this.getTailwind()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.web.NextJsCommonProjectOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            NextJsCommonProjectOptions.Jsii$Proxy that = (NextJsCommonProjectOptions.Jsii$Proxy) o;

            if (this.assetsdir != null ? !this.assetsdir.equals(that.assetsdir) : that.assetsdir != null) return false;
            return this.tailwind != null ? this.tailwind.equals(that.tailwind) : that.tailwind == null;
        }

        @Override
        public final int hashCode() {
            int result = this.assetsdir != null ? this.assetsdir.hashCode() : 0;
            result = 31 * result + (this.tailwind != null ? this.tailwind.hashCode() : 0);
            return result;
        }
    }
}
